*                          MICRON HSPICE MODEL
*
* Disclaimer:    This software code and all associated documentation, comments
*                or other information (collectively "Software") is provided
*                "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*                ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*                INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*                RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*                FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*                SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*                THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*                MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*                RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*                ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*                OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*                EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*                LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*                SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*                OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*                ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*                EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*                Because some jurisdictions prohibit the exclusion or limitation
*                of liability for consequential or incidental damages, the above
*                limitation may not apply to you.
* 
*                Copyright 2011 Micron Technology, Inc. All rights reserved.
*
**** 512Megx4, 256Megx8 TwinDie DDR2 SDRAM ****
**** Example HSPICE setup for A0 ****

****************************************************************************
****                ___                                                    *
****               /  +|--NODE_U1_72--|                                    *
**** RCVR_OUT_U1--{   -|-----VREF     |                                    *
****               \___|--RCVREN      | ---------------------------        *
****                                  |-| A0 Package Model        |        *
****                                    |                         |-PIN_H8 *
****                                  |-| u68ax8_2cob_A0.mod      |        *
****                ___               | ---------------------------        *
****               /  +|--NODE_U0_72--|                                    *
**** RCVR_OUT_U0--{   -|-----VREF                                          *
****               \___|--RCVREN                                           *
****                                                                       *
****************************************************************************

**** The input signal is PIN_H8.
**** The output of the input receiver circuit is the node RCVR_OUT.

**** The .LIB statement selects the following simulation corners:
****   LIB           DATARATE       PROCESS  DIE CAP  VDD/VDDQ  TEMPERATURE
****   ---           -------------  -------  -------  --------  -----------
****   TYP_533       400/533 Mbps   Typical  Typical  1.800V    50C
****   SLOW_533      400/533 Mbps   Weak     Maximum  1.700V    100C
****   FAST_533      400/533 Mbps   Strong   Minimum  1.900V    0C

****   TYP_667       667 Mbps       Typical  Typical  1.800V    50C
****   SLOW_667      667 Mbps       Weak     Maximum  1.700V    100C
****   FAST_667      667 Mbps       Strong   Minimum  1.900V    0C

****   TYP_800       800 Mbps       Typical  Typical  1.800V    50C
****   SLOW_800      800 Mbps       Weak     Maximum  1.700V    100C
****   FAST_800      800 Mbps       Strong   Minimum  1.900V    0C

**** The files needed to run this simulation include u68a_stacked_model.cnr,
**** u68a_inbuff.inc and u68ax8_2cob_A0.mod.

**** Commercial Temperature settings are: Typical 50C, Slow 100C, Fast 0C
**** Industrial Temperature settings are: Typical 50C, Slow 110C, Fast -40C

.OPTIONS POST 
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH='./u68a_die_model_hspice'
.OPTIONS SEARCH='./u68ax8_2cob_hspice'
.INC "u68ax8_2cob_A0.mod"

.TRAN 0.010ns '4*per'

.LIB "u68a_stacked_model.cnr" TYP_533
*.LIB "u68a_stacked_model.cnr" TYP_667
*.LIB "u68a_stacked_model.cnr" TYP_800

.TITLE Typical

**** The temperature is for the typical case
.TEMP 50    $Nominal Junction Temp for CT and IT


****************************************************************
**** POWER SUPPLY PARAMETERS
****************************************************************
.PARAM  vcc_typ   = 1.800V
.PARAM  vcc_min   = 1.700V
.PARAM  vcc_max   = 1.900V

.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V
**vccr is internally regulated voltage

.PARAM  vss       = 0.0V
.PARAM  gnd       = 0.0V
.PARAM  vssq      = 0.0V

**** Match up typ, min, or max voltages for corner sims*********
.PARAM  vccq      = vcc
.PARAM  vcc       = vcc_typ
.PARAM  vccr      = vccr_typ
**************************************************************** 
Vvcc    vcc   0  DC = vcc
Vvccr   vccr  0  DC = vccr
Vvss    vss   0  DC = vss
Vref    vref  0  DC = 'vccq/2' 


****************************************************************
**** RECEIVER ENABLE SIGNAL
****************************************************************
**** Active high (vccr) receiver enable, Active low (vss) to disable
Ven  RCVR_EN  0  DC = vccr

****************************************************************
**** INPUT SIGNAL
****************************************************************
**** Input Stimulus Parameters

.param datarate = 533.33E6
*.param datarate = 666.67E6
*.param datarate = 800.00E6
.PARAM input_rate = 'datarate/2'
.PARAM pulsewidth = '1/input_rate - dataslew'
.PARAM per = '2*(1/input_rate)'
.PARAM delay = 1ns
.PARAM dataslew = 400p

**** Vin toggles the INPUT at the input rate specified above (1/2 datarate)
Vin   PIN_H8  0  PULSE vss vcc delay dataslew dataslew pulsewidth per


****************************************************************
**** TOP CELL:  u68a_inbuff
***************************************************************
**** Bottom Die
xi0 RCVR_OUT_U0 NODE_U0_72 RCVR_EN VREF vss vccr vcc u68a_inbuff
**** Top Die
xi1 RCVR_OUT_U1 NODE_U1_72 RCVR_EN VREF vss vccr vcc u68a_inbuff

****************************************************************
**** PACKAGE CONNECTION
****************************************************************

X_pkg PIN_H8 NODE_U0_72 NODE_U1_72 A0

****************************************************************
**** ALTER STATEMENTS
****************************************************************
.ALTER

.TITLE Slow

.PARAM  vcc         = vcc_min
.PARAM  vccr        = vccr_min

.TEMP 100    $Max Junction Temp for CT
.LIB "u68a_stacked_model.cnr" SLOW_533
*.LIB "u68a_stacked_model.cnr" SLOW_667
*.LIB "u68a_stacked_model.cnr" SLOW_800

****************************************************************
.ALTER

.TITLE Fast

.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max

.TEMP 0      $Min Junction Temp for CT
*.TEMP -40      $Min Junction Temp for IT
.LIB "u68a_stacked_model.cnr" FAST_533
*.LIB "u68a_stacked_model.cnr" FAST_667
*.LIB "u68a_stacked_model.cnr" FAST_800

****************************************************************

.END
