*                          MICRON HSPICE MODEL
*
* Disclaimer:    This software code and all associated documentation, comments
*                or other information (collectively "Software") is provided
*                "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*                ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*                INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*                RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*                FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*                SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*                THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*                MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*                RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*                ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*                OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*                EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*                LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*                SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*                OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*                ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*                EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*                Because some jurisdictions prohibit the exclusion or limitation
*                of liability for consequential or incidental damages, the above
*                limitation may not apply to you.
* 
*                Copyright 2011 Micron Technology, Inc. All rights reserved.
*
**** 512Megx4, 256Megx8 TwinDie DDR2 SDRAM ****
**** Example HSPICE setup for DQ0 ****

*********************************************************************************
****                ____                                                        *
****    IN_U1/CKD--|    \                                                       *
**** Control bits--|     }----NODE_U1_38--|                                     *
****     ENOUT_U1--|____/   |             |                                     *
****                        |             |                                     *
****                  ___   |             |                                     *
****                 /  +|--|             | ----------------------------        *
****   RCVR_OUT_U1--{   -|-----VREF       |-| DQ0 Package Model        |        *
****                 \___|-(ENOUT_U1#)      |                          |-PIN_C8 *
****                                      |-| u68ax8_2cob_DQ0.mod      |        *
****                ____                  | ----------------------------        *
****    IN_U0/CKD--|    \                 |                                     *
**** Control bits--|     }----NODE_U0_38--|                                     *
****     ENOUT_U0--|____/   |                                                   *
****                        |                                                   *
****                  ___   |                                                   *
****                 /  +|--|                                                   *
****   RCVR_OUT_U0--{   -|-----VREF                                             *
****                 \___|-(ENOUT_U1#)                                          *
****                                                                            *
*********************************************************************************


**** The input signals are IN (input signal) and ENOUT (output enable signal).
**** ODT_EN controls the On-Die Termination enable/disable functionality.
**** The I/O data is available on the signal PIN_C8.
**** The output of the input receiver circuit is the node RCVR_OUT.

**** The .LIB statement selects the following simulation corners:
****   LIB           DATARATE       PROCESS  DIE CAP  VDD/VDDQ  TEMPERATURE
****   ---           -------------  -------  -------  --------  -----------
****   TYP_533       400/533 Mbps   Typical  Typical  1.800V    50C
****   SLOW_533      400/533 Mbps   Weak     Maximum  1.700V    100C
****   FAST_533      400/533 Mbps   Strong   Minimum  1.900V    0C

****   TYP_667       667 Mbps       Typical  Typical  1.800V    50C
****   SLOW_667      667 Mbps       Weak     Maximum  1.700V    100C
****   FAST_667      667 Mbps       Strong   Minimum  1.900V    0C

****   TYP_800       800 Mbps       Typical  Typical  1.800V    50C
****   SLOW_800      800 Mbps       Weak     Maximum  1.700V    100C
****   FAST_800      800 Mbps       Strong   Minimum  1.900V    0C

**** The files needed to run this simulation include u68a_stacked_model.cnr,
**** u68a_dqbuff.inc and u68ax8_2cob_DQ0.mod.

**** Commercial Temperature settings are: Typical 50C, Slow 100C, Fast 0C
**** Industrial Temperature settings are: Typical 50C, Slow 110C, Fast -40C

.OPTIONS POST 
.OPTIONS METHOD=GEAR
.OPTIONS SEARCH='./u68a_die_model_hspice'
.OPTIONS SEARCH='./u68ax8_2cob_hspice'
*.OPTIONS SEARCH='./u68ax4_2cob_hspice' $ Search path for x4 package models
.INC "u68ax8_2cob_DQ0.mod"
*.INC "u68ax4_2cob_DQ0.mod" $ Include path for x4 package DQ0 model

.TRAN 0.010ns '10*per'

.LIB "u68a_stacked_model.cnr" TYP_533
*.LIB "u68a_stacked_model.cnr" TYP_667
*.LIB "u68a_stacked_model.cnr" TYP_800

.TITLE Typical

**** The temperature is for the typical case
.TEMP 50    $Nominal Junction Temp for CT and IT

****************************************************************
**** POWER SUPPLY PARAMETERS
****************************************************************
.PARAM  vccq_typ  = 1.800V
.PARAM  vccq_min  = 1.700V
.PARAM  vccq_max  = 1.900V

.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V
**vccr is internally regulated voltage

.PARAM  vss       = 0.0V
.PARAM  gnd       = 0.0V
.PARAM  vssq      = 0.0V

**** Match up typ, min, or max voltages for corner sims*********
.PARAM  vccq      = vccq_typ
.PARAM  vccr      = vccr_typ
**************************************************************** 
Vvccq   vccq  0  DC = vccq
Vvccr   vccr  0  DC = vccr
Vvssq   vssq  0  DC = vssq
Vvss    vss   0  DC = vss
Vref    vref  0  DC = 'vccq/2' 
Vvtt    vtt   0  DC = 'vccq/2' 

*****************************************************************************
**On-Die Termination is controlled like the Extended Mode Register settings**
*****************************************************************************
**Bit Settings: EMR Bit 6     EMR Bit 2     Function    **
**                  0             0         disabled    **
**                  0             1         75 ohm ODT  **
**                  1             0         150 ohm ODT **
**                  1             1         50 ohm ODT  **
**********************************************************
Vodt_emr6  odt_emr6 0  DC = vss  $ see table above for settings
Vodt_emr2  odt_emr2 0  DC = vccr $ 0 = gnd, 1 = vccr
**********************************************************
**** Active high ODT enable, set odten to vccr/vss to toggle ODT on/off
Vodten_U0    ODT_EN_U0   0  DC = vss
Vodten_U1    ODT_EN_U1   0  DC = vss

**The fulldrv node selects between Full and Reduced output drive strengths.
Vdrv  FULLDRV 0  DC = vccr  $vccr = 100%, vss = 60%

****************************************************************
**** OUTPUT ENABLE SIGNAL
****************************************************************
**** Active high (vccr) for output, Active low (vss) for input
**** Only one die at a time should have ENOUT set high for output
Ven0  enout_U0 0   DC = vccr
Ven1  enout_U1 0   DC = vss

****************************************************************
**** INPUT SIGNAL
****************************************************************
**** Input Stimulus Parameters

.param datarate = 533.33E6
*.param datarate = 666.67E6
*.param datarate = 800.00E6
.PARAM pulsewidth = '1/datarate - dataslew'
.PARAM per = '2*(1/datarate)'
.PARAM delay = 2ns
.PARAM dataslew = 50ps

**** Vin toggles the DQ at the datarate specified above
Vin0   IN_U0    0  LFSR vss vccr delay dataslew dataslew datarate 1 [5 2]
Vin1   IN_U1    0  DC = vss


****************************************************************
**** TOP CELL:  u68a_dqbuff
****************************************************************
**** Bottom Die
xi0 RCVR_OUT_U0 NODE_U0_38 ENOUT_U0 FULLDRV IN_U0 ODT_EMR2 ODT_EMR6 ODTEN_U0 VREF vss vccr vccq vssq u68a_dqbuff
**** Top Die
xi1 RCVR_OUT_U1 NODE_U1_38 ENOUT_U1 FULLDRV IN_U1 ODT_EMR2 ODT_EMR6 ODTEN_U1 VREF vss vccr vccq vssq u68a_dqbuff

****************************************************************
**** PACKAGE CONNECTION
****************************************************************

X_pkg PIN_C8 NODE_U0_38 NODE_U1_38 DQ0

**** LOAD CIRCUIT
Rtt PIN_C8 vtt r=25

****************************************************************
**** ALTER STATEMENTS
****************************************************************
.ALTER

.TITLE Slow

.PARAM  vccq        = vccq_min
.PARAM  vccr        = vccr_min

.TEMP 100    $Max Junction Temp for CT
.LIB "u68a_stacked_model.cnr" SLOW_533
*.LIB "u68a_stacked_model.cnr" SLOW_667
*.LIB "u68a_stacked_model.cnr" SLOW_800


****************************************************************
.ALTER

.TITLE Fast

.PARAM  vccq        = vccq_max
.PARAM  vccr        = vccr_max

.TEMP 0      $Min Junction Temp for CT
*.TEMP -40      $Min Junction Temp for IT
.LIB "u68a_stacked_model.cnr" FAST_533
*.LIB "u68a_stacked_model.cnr" FAST_667
*.LIB "u68a_stacked_model.cnr" FAST_800

****************************************************************
.ALTER

.TITLE Write Mode

.PARAM  vccq        = vccq_typ
.PARAM  vccr        = vccr_typ

.TEMP 50    $Nominal Junction Temp for CT and IT
.LIB "u68a_stacked_model.cnr" TYP_533
*.LIB "u68a_stacked_model.cnr" TYP_667
*.LIB "u68a_stacked_model.cnr" TYP_800

**** ENOUT should be set low for both die in Write Mode
Ven0    enout_U0   0  DC = vss

**** ODTEN typically set high for one die only
Vodten_U0    odten_U0   0  DC = vccr

Vwrite  PIN_C8 0  pulse vssq vccq delay dataslew dataslew pulsewidth per
.param dataslew = 300ps

****************************************************************

.END
