*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2011 Micron Technology, Inc. All rights reserved.
*
************** 256Megx4, 128Megx8, 64Megx8 DDR-2 SDRAM ***********************
********Example HSPICE setup file for DQS & DQS# (when DQS# is enabled)******
****
***********************************************************
****           ____                                       *
****      IN--|    \                                      *
****          |     }------PAD--\/\/\/--@@@@--|--PKG_OUT  *
****   ENOUT--|____/          |  R_pkg  L_pkg |           *
****                          |              ===C_pkg     *
****             ___          |               |           *
****            /  +|----------              GND          *
**** RCVR_OUT--{   -|----------                           *
****            \___|-(ENOUT#)|                           *
****           ____           |                           *
****     IN_--|    \          |                           *
****          |     }----PAD_---\/\/\/--@@@@--|--PKG_OUT_ *
****   ENOUT--|____/            Rn_pkg Ln_pkg |           *
****                                         ===Cn_pkg    *
****                                          |           *
****                                         GND          *
***********************************************************
****
**** This netlist is for the x4, x8, x16 1Gb DDRII SDRAM 
**** The input signals are IN/IN_ (input signal) and ENOUT (output enable signal).
**** The I/O data is available on the signal PAD/PAD_.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.
****
**** NOTE: This spice file is not designed to match datasheet timing numbers.
****       Delay times are smaller than those given in the data sheets.
****
**** The .LIB statement selects the following simulation corners:
****   LIB        DATARATE       PROCESS  DIE CAP  VDD/VDDQ
****   ---        --------       -------  -------  --------
****   TYP_533    400/533 Mbps   Typical  Typical  1.800V
****   SLOW_533   400/533 Mbps   Weak     Maximum  1.700V
****   FAST_533   400/533 Mbps   Strong   Minimum  1.900V
****
****   TYP_667    667 Mbps       Typical  Typical  1.800V
****   SLOW_667   667 Mbps       Weak     Maximum  1.700V
****   FAST_667   667 Mbps       Strong   Minimum  1.900V
****
****   TYP_800    800 Mbps       Typical  Typical  1.800V
****   SLOW_800   800 Mbps       Weak     Maximum  1.700V
****   FAST_800   800 Mbps       Strong   Minimum  1.900V
****
****   TYP_1066   800 Mbps       Typical  Typical  1.800V
****   SLOW_1066  800 Mbps       Typical  Maximum  1.700V
****   FAST_1066  800 Mbps       Strong   Minimum  1.900V
****
**** To run this simulation, the files "u68a_stacked_model.cnr" and "u68a_dqsbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Commercial temperature settings are: Typical 50C, Slow 100C, Fast 0C
**** Industrial temperature settings are: Typical 50C, Slow 110C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 120C, Fast -40C
***********************************************************

.OPTIONS POST
.OPTIONS METHOD=GEAR
.OPTIONS GSHUNT=1E-12
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns '12*per' start=delay 

.LIB "u68a_stacked_model.cnr" TYP_533
*.LIB "u68a_stacked_model.cnr" TYP_667
*.LIB "u68a_stacked_model.cnr" TYP_800
*.LIB "u68a_stacked_model.cnr" TYP_1066

.TITLE Nominal Full Drive

**** Temperature is for typical case (CT=50C, IT=50C, AT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
**** vccr internal regulated power supply

.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  vccq_typ  = 1.800V
.PARAM  vccq_min  = 1.700V
.PARAM  vccq_max  = 1.900V

.PARAM  gnd       = 0.000V
.PARAM  vssq      = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vccq      = vccq_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvccq   vccq  0  DC = vccq
Vvccr   vccr  0  DC = vccr 
Vvssq   vssq  0  DC = vssq
Vvref   vref  0  DC = '0.5*vccq'
Vvss    vss   0  DC = vss
Vvtt    vtt   0  DC = '0.5*vccq'

***********************************************************
**** OUTPUT ENABLE SIGNAL  
***********************************************************
**** Active high for output, Active low for input
Ven    enout  0  DC = vccr

***********************************************************
**** INPUT SIGNAL  
***********************************************************
**** Input Stimulus Parameters

*.PARAM datarate = 400.00E6
.PARAM datarate = 533.33E6
*.PARAM datarate = 666.67E6
*.PARAM datarate = 800.00E6
*.PARAM datarate = 1066.67E6
.PARAM pulsewidth = '1/datarate - dataslew'
.PARAM per = '2*(1/datarate)'
.PARAM delay = 2ns
.PARAM dataslew = 150ps

**** Vin toggles the DQS at the datarate specified above
Vin    IN     0  PULSE vss vccr delay dataslew dataslew pulsewidth per
**** Vin_ toggles the DQS# at the datarate specified above
Vin_   IN_    0  PULSE vccr vss delay dataslew dataslew pulsewidth per

***********************************************************
**** TOP CELL:  u68a_dqsbuff
***********************************************************
xi0 RCVR_OUT PAD PAD_ ENOUT FULLDRV IN IN_ ODT_EMR2 ODT_EMR6 ODT_EN vss vccr vccq vssq u68a_dqsbuff

***********************************************************
**** ODT SETUP
***********************************************************
**** On-Die Termination is controlled like the Extended Mode Register settings
****   EMR Bit 6     EMR Bit 2     Function
****       0             0         Disabled
****       0             1         75 ohm ODT
****       1             0         150 ohm ODT
****       1             1         50 ohm ODT

**** Active high ODT enable, set odt_en to vccr/gnd and set the EMR bits 
**** to toggle ODT on/off

VODT_EN   ODT_EN   gnd DC = 0
VODT_EMR2 ODT_EMR2 gnd DC = 0 
VODT_EMR6 ODT_EMR6 gnd DC = 0

***********************************************************
**** DRIVE STRENGTH
***********************************************************
**** The fulldrv node selects between Full and Reduced output drive strengths

VFULLDRV FULLDRV gnd DC = vccr $vccr = 100%, gnd = 45%

***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad  PAD  PKG_OUT  pkg  r=196.43m l=1.79nH c=0.32pF 
x_pkg_pad_ PAD_ PKG_OUT_ pkg  r=221.25m l=1.93nH c=0.39pF 

rtt  pkg_out  vtt r=25
rtt_ pkg_out_ vtt r=25

.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
**** ALTER STATEMENTS
***********************************************************
.ALTER

.TITLE Nominal Half Drive

VFULLDRV FULLDRV gnd dc=gnd

***********************************************************
.ALTER

.TITLE Weak

VFULLDRV FULLDRV gnd dc=vccr

.PARAM  vccq        = vccq_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (CT=100C, IT=110C, AT=120C)
.TEMP 100

.LIB "u68a_stacked_model.cnr" SLOW_533
*.LIB "u68a_stacked_model.cnr" SLOW_667
*.LIB "u68a_stacked_model.cnr" SLOW_800
*.LIB "u68a_stacked_model.cnr" SLOW_1066

***********************************************************
.ALTER

.TITLE Strong

.PARAM  vccq        = vccq_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (CT=0C, IT=-40C, AT=-40C)
.TEMP 0

.LIB "u68a_stacked_model.cnr" FAST_533
*.LIB "u68a_stacked_model.cnr" FAST_667
*.LIB "u68a_stacked_model.cnr" FAST_800
*.LIB "u68a_stacked_model.cnr" FAST_1066

***********************************************************
.ALTER

.TITLE Write Mode 

.PARAM  vccq        = vccq_typ
.PARAM  vccr        = vccr_typ

.TEMP 50

Ven       enout   0  DC = gnd

Vpkg_out  pkg_out   0  PULSE 0 vccq delay dataslew dataslew pulsewidth per
Vpkg_out_ pkg_out_  0  PULSE vccq 0 delay dataslew dataslew pulsewidth per

***********************************************************
.END
