*                         MICRON HSPICE MODEL
*
* Disclaimer: This software code and all associated documentation, comments
*             or other information (collectively "Software") is provided
*             "AS IS" without warranty of any kind. MICRON TECHNOLOGY, INC.
*             ("MTI") EXPRESSLY DISCLAIMS ALL WARRANTIES EXPRESS OR IMPLIED,
*             INCLUDING BUT NOT LIMITED TO, NONINFRINGEMENT OF THIRD PARTY
*             RIGHTS, AND ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
*             FOR ANY PARTICULAR PURPOSE. MTI DOES NOT WARRANT THAT THE
*             SOFTWARE WILL MEET YOUR REQUIREMENTS, OR THAT THE OPERATION OF
*             THE SOFTWARE WILL BE UNINTERRUPTED OR ERROR-FREE. FURTHERMORE,
*             MTI DOES NOT MAKE ANY REPRESENTATIONS REGARDING THE USE OR THE
*             RESULTS OF THE USE OF THE SOFTWARE IN TERMS OF ITS CORRECTNESS,
*             ACCURACY, RELIABILITY, OR OTHERWISE. THE ENTIRE RISK ARISING OUT
*             OF USE OR PERFORMANCE OF THE SOFTWARE REMAINS WITH YOU. IN NO
*             EVENT SHALL MTI, ITS AFFILIATED COMPANIES OR THEIR SUPPLIERS BE
*             LIABLE FOR ANY DIRECT, INDIRECT, CONSEQUENTIAL, INCIDENTAL, OR
*             SPECIAL DAMAGES (INCLUDING, WITHOUT LIMITATION, DAMAGES FOR LOSS
*             OF PROFITS, BUSINESS INTERRUPTION, OR LOSS OF INFORMATION)
*             ARISING OUT OF YOUR USE OF OR INABILITY TO USE THE SOFTWARE,
*             EVEN IF MTI HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGES.
*             Because some jurisdictions prohibit the exclusion or limitation
*             of liability for consequential or incidental damages, the above
*             limitation may not apply to you.
* 
*             Copyright 2011 Micron Technology, Inc. All rights reserved.
*
************** 256Megx4, 128Megx8, 64Megx8 DDR-2 SDRAM ***********************
*******Example HSPICE setup for all input circuits except CLK/CLK# & DM*******
****
***********************************************************
****             ___                                      *
****            /  +|-PAD----\/\/\/--@@@@--------PKG_IN   *
**** RCVR_OUT--{   -|-VREF   R_pkg  L_pkg     |           *
****            \___|-RCVREN                 ===C_pkg     *
****                                          |           *
****                                         GND          *
***********************************************************
****
**** This netlist is for the x4, x8, x16 1Gb DDRII SDRAM 
**** The RCVREN signal is output enable.
**** The Input signal is PAD.
**** The output of the input receiver circuit is the node RCVR_OUT.
**** To account for package parasitics correlative impedance values
**** (netlist elements R_pkg, L_pkg, C_pkg) have been attached to the PAD
**** node.  The package output is on the signal PKG_OUT.
****
**** The .LIB statement selects the following simulation corners:
****   LIB        DATARATE       PROCESS  DIE CAP  VDD/VDDQ
****   ---        --------       -------  -------  --------
****   TYP_533    400/533 Mbps   Typical  Typical  1.800V
****   SLOW_533   400/533 Mbps   Weak     Maximum  1.700V
****   FAST_533   400/533 Mbps   Strong   Minimum  1.900V
****
****   TYP_667    667 Mbps       Typical  Typical  1.800V
****   SLOW_667   667 Mbps       Weak     Maximum  1.700V
****   FAST_667   667 Mbps       Strong   Minimum  1.900V
****
****   TYP_800    800 Mbps       Typical  Typical  1.800V
****   SLOW_800   800 Mbps       Weak     Maximum  1.700V
****   FAST_800   800 Mbps       Strong   Minimum  1.900V
****
****   TYP_1066   800 Mbps       Typical  Typical  1.800V
****   SLOW_1066  800 Mbps       Typical  Maximum  1.700V
****   FAST_1066  800 Mbps       Strong   Minimum  1.900V
****
**** To run this simulation, the files "u68a_stacked_model.cnr" and "u68a_inbuff.inc"
**** are required to be in the same directory as this netlist.
****
**** Commercial temperature settings are: Typical 50C, Slow 100C, Fast 0C
**** Industrial temperature settings are: Typical 50C, Slow 110C, Fast -40C
**** Automotive temperature settings are: Typical 50C, Slow 120C, Fast -40C
***********************************************************

.OPTIONS POST
.OPTIONS METHOD=GEAR
.OPTIONS GSHUNT=1E-12
.OPTIONS SEARCH=' '  $This option must be present for decryption to work

.TRAN 0.01ns '6*per' start=delay 

.LIB "u68a_stacked_model.cnr" TYP_533
*.LIB "u68a_stacked_model.cnr" TYP_667
*.LIB "u68a_stacked_model.cnr" TYP_800
*.LIB "u68a_stacked_model.cnr" TYP_1066

.TITLE Nominal Full Drive

**** Temperature is for typical case (CT=50C, IT=50C, AT=50C)
.TEMP 50

***********************************************************
**** POWER SUPPLY PARAMETER 
***********************************************************
**** vccr internal regulated power supply

.PARAM  vccr_typ  = 1.300V
.PARAM  vccr_min  = 1.250V
.PARAM  vccr_max  = 1.350V

.PARAM  vcc_typ   = 1.800V
.PARAM  vcc_min   = 1.700V
.PARAM  vcc_max   = 1.900V

.PARAM  gnd       = 0.000V
.PARAM  vssq      = 0.000V
.PARAM  vss       = 0.000V

**** Match up typ, min, or max voltages for corner sims
.PARAM  vcc       = vcc_typ
.PARAM  vccr      = vccr_typ

***********************************************************
Vvcc    vcc  0   DC = vcc
Vvccr   vccr 0   DC = vccr 
Vvssq   vssq 0   DC = vssq
Vvref   vref 0   DC = '0.5*vcc'
Vvss    vss  0   DC = vss
Vvtt    vtt  0   DC = '0.5*vcc'

***********************************************************
**** INPUT SIGNAL  
***********************************************************
**** Input Stimulus Parameters

*.PARAM datarate = 400.00E6
.PARAM datarate = 533.33E6
*.PARAM datarate = 666.67E6
*.PARAM datarate = 800.00E6
*.PARAM datarate = 1066.67E6
.PARAM input_rate = 'datarate/2'
.PARAM pulsewidth = '1/input_rate - dataslew'
.PARAM per = '2*(1/input_rate)'
.PARAM delay = 1ns
.PARAM dataslew = 400p

**** Vin toggles the INPUT at the input rate specified above (1/2 datarate)
Vin   PKG_IN  0  PULSE vss vcc delay dataslew dataslew pulsewidth per

***********************************************************
**** RECEIVER ENABLE SIGNAL  
***********************************************************
**** Active high for receiver output
Ven    rcvr_en  0  DC = vccr

***********************************************************
**** TOP CELL:  u68a_inbuff
***********************************************************
xi0 RCVR_OUT PAD RCVR_EN VREF vss vccr vcc u68a_inbuff

***********************************************************
**** PACKAGE CONNECTION
***********************************************************
**** Refer to the IBIS model for specific package parasitic values.

x_pkg_pad PAD PKG_IN pkg  r=148.22m l=1.59nH c=0.27pF 

.SUBCKT pkg pad pkg_out r=0 l=0 c=0
r_pkg pad net1 R='r'
l_pkg net1 pkg_out L='l'
c_pkg pkg_out gnd C='c'
.ENDS pkg

***********************************************************
.ALTER

.TITLE Weak

.PARAM  vcc         = vcc_min
.PARAM  vccr        = vccr_min

**** Temperature is for slow case (CT=100C, IT=110C, AT=120C)
.TEMP 100

.LIB "u68a_stacked_model.cnr" SLOW_533
*.LIB "u68a_stacked_model.cnr" SLOW_667
*.LIB "u68a_stacked_model.cnr" SLOW_800
*.LIB "u68a_stacked_model.cnr" SLOW_1066

***********************************************************
.ALTER

.TITLE Strong

.PARAM  vcc         = vcc_max
.PARAM  vccr        = vccr_max

**** Temperature is for fast case (CT=0C, IT=-40C, AT=-40C)
.TEMP 0

.LIB "u68a_stacked_model.cnr" FAST_533
*.LIB "u68a_stacked_model.cnr" FAST_667
*.LIB "u68a_stacked_model.cnr" FAST_800
*.LIB "u68a_stacked_model.cnr" FAST_1066

***********************************************************
.ALTER

.TITLE Disable Receiver

Ven   rcvr_en   0  DC = gnd

***********************************************************
.END
